@@ -1,25 +1,26 @@
 # Copyrights 2006-2007 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.00.
+# Pod stripped from pm file by OODoc 1.02.
 use warnings;
 use strict;
 
 package XML::Compile::Schema::BuiltInTypes;
 use vars '$VERSION';
-$VERSION = '0.18';
+$VERSION = '0.5';
 use base 'Exporter';
 
 our @EXPORT = qw/%builtin_types/;
 
 our %builtin_types;
 
+use Log::Report 'xml-compile', syntax => 'SHORT';
 use MIME::Base64;
-use POSIX            qw/strftime/;
-use Carp             qw/croak/;
-
+use POSIX              qw/strftime/;
 # use XML::RegExp;  ### can we use this?
 
+use XML::Compile::Util qw/pack_type/;
+
 
 # The XML reader calls
 #     check(parse(value))  or check_read(parse(value))
@@ -27,10 +28,30 @@ use Carp             qw/croak/;
 #     check(format(value)) or check_write(format(value))
 
 sub identity { $_[0] };
-sub str2int  { use warnings FATAL => 'all'; eval {$_[0] + 0} };
-sub int2str  { use warnings FATAL => 'all'; eval {sprintf "%ld", $_[0]} };
-sub str2num  { use warnings FATAL => 'all'; eval {$_[0] + 0.0} };
-sub num2str  { use warnings FATAL => 'all'; eval {sprintf "%lf", $_[0]} };
+sub str2int
+{   my $v = eval { use warnings FATAL => 'all'; $_[0] + 0};
+    $@ && error __x $@;
+    $v;
+}
+
+sub int2str
+{   my $v = eval { use warnings FATAL => 'all'; sprintf "%ld", $_[0]};
+    $@ && error __x $@;
+    $v;
+}
+
+sub str2num
+{   my $v = eval { use warnings FATAL => 'all'; $_[0] + 0.0};
+    $@ && error __x $@;
+    $v;
+}
+
+sub num2str
+{   my $v = eval { use warnings FATAL => 'all'; sprintf "%lf", $_[0]};
+    $@ && error __x $@;
+    $v;
+}
+
 sub str      { "$_[0]" };
 sub collapse { $_[0] =~ s/\s+//g; $_[0]}
 sub preserve { for($_[0]) {s/\s+/ /g; s/^ //; s/ $//}; $_[0]}
@@ -404,8 +425,9 @@ $builtin_types{QName} =
      sub { my ($qname, $node) = @_;
            my $prefix = $qname =~ s/^([^:]*)\:// ? $1 : '';
            my $ns = $node->lookupNamespaceURI($prefix)
-               or croak "ERROR: cannot find prefix $prefix for QNAME $qname";
-           "{$ns}$qname";
+               or error __x"cannot find prefix `{prefix}' for QNAME `{qname}'"
+                     , prefix => $prefix, qname => $qname;
+           pack_type($ns, $qname);
          }
  , check   => \&_valid_qname
  , example => 'myns:name'
