@@ -1,13 +1,13 @@
 # Copyrights 2006-2007 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.00.
+# Pod stripped from pm file by OODoc 1.02.
 use warnings;
 use strict;
 
 package TestTools;
 use vars '$VERSION';
-$VERSION = '0.18';
+$VERSION = '0.5';
 use base 'Exporter';
 
 use XML::LibXML;
@@ -16,6 +16,8 @@ use Test::Deep   qw/cmp_deeply/;
 
 use XML::Compile::Dumper;
 use POSIX        qw/_exit/;
+use Log::Report  qw/try/;
+use Data::Dumper qw/Dumper/;
 
 # avoid refcount errors perl 5.8.8, libxml 2.6.26, XML::LibXML 2.60,
 # and Data::Dump::Streamer 2.03;  actually, the bug can be anywhere...
@@ -30,8 +32,10 @@ our @EXPORT = qw/
  $dump_pkg
  @run_opts
  reader
+ reader_error
  writer
  writer_test
+ writer_error
  compare_xml
  test_rw
  templ_xml
@@ -59,6 +63,25 @@ sub reader($$$@)
     $read_t;
 }
 
+sub reader_error($$$)
+{   my ($schema, $test, $xml) = @_;
+    my $type  = $test =~ m/\{/ ? $test : "{$TestNS}$test";
+    my $r     = reader($schema, $test, $type);
+    defined $r or return;
+
+    my $tree  = try { $r->($xml) };
+    my $error
+       = ref $@ && $@->exceptions
+       ? join("\n", map {$_->message} $@->exceptions)
+       : '';
+    undef $tree if $error;   # there is output if only warnings are produced
+
+    ok(!defined $tree, "no return for $test");
+    warn "RETURNED TREE=",Dumper $tree if defined $tree;
+    ok(length $error, "ER=$error");
+    $error;
+}
+
 # check whether the dumped code produces the same HASH as
 # the freshly compiled code.
 my $lab = 1;
@@ -104,7 +127,7 @@ sub writer($$$@)
      );
 
     ok(defined $write_t, "writer element $test");
-    defined $write_t or next;
+    defined $write_t or return;
 
     cmp_ok(ref($write_t), 'eq', 'CODE');
     $write_t;
@@ -124,6 +147,32 @@ sub writer_test($$;$)
     $tree;
 }
 
+sub writer_error($$$)
+{   my ($schema, $test, $data) = @_;
+    my $type  = $test =~ m/\{/ ? $test : "{$TestNS}$test";
+
+    my $write = writer($schema, $type, $type);
+    ok(defined $write, "created writer $test");
+    is(ref $write, 'CODE');
+    my $node;
+    try { my $doc = XML::LibXML->createDocument('test doc', 'utf-8');
+          isa_ok($doc, 'XML::LibXML::Document');
+          $node = $write->($doc, $data);
+    };
+ 
+    my $error
+       = ref $@ && $@->exceptions
+       ? join("\n", map {$_->message} $@->exceptions)
+       : '';
+    undef $node if $error;   # there is output if only warnings are produced
+
+#   my $error = $@ ? $@->wasFatal->message : '';
+    ok(!defined $node, "no return for $test");
+    warn "RETURNED =", $node->toString if ref $node;
+    ok(length $error, "EW=$error");
+    $error;
+}
+
 # check whether the dumped code produces the same XML as
 # the freshly compiled code.
 sub writer_dump($$)
@@ -171,7 +220,6 @@ sub test_rw($$$$;$$)
 
     my $h = $r->($xml);
 
-#use Data::Dumper;
 #warn Dumper $h;
     unless(defined $h)   # avoid crash of is_deeply
     {   if(defined $expect && length($expect))
@@ -183,7 +231,6 @@ sub test_rw($$$$;$$)
         return;
     }
 
-#use Data::Dumper;
 #warn Dumper $h, $hash;
     cmp_deeply($h, $hash, "from xml");
 
@@ -213,7 +260,8 @@ sub compare_xml($$)
 {   my ($tree, $expect) = @_;
     my $dump = ref $tree ? $tree->toString : $tree;
 
-    if($dump =~ m/\n|\s\s/)
+    if(!defined $dump) { ; }
+    elsif($dump =~ m/\n|\s\s/)
     {   # output expects superfluous blanks
         $expect =~ s/\n\z//;
     }
